@@ -7,6 +7,7 @@ import numpy as np
 
 from PIL import Image
 import requests 
+from urllib import parse
 
 def put_qiniu(np,
         access_key:str, 
@@ -32,7 +33,6 @@ def url_to_array(url):
     result = requests.get(url, timeout=3)
     if result.ok:
         img = Image.open(io.BytesIO(result.content))
-        img =  img.convert('RGBA')
         data =  np.array(img)
         return data
     else:
@@ -42,4 +42,12 @@ def url_to_array(url):
 def file_to_array(path):
     f = Image.open(path)
     data = imagetool.img_to_array(f)
-    return data
\ No newline at end of file
+    return data
+
+def url_to_file(url,filepath = None):
+    d = url_to_array(url)
+    if filepath is None:
+        p = parse.urlparse(url)
+        filepath = p.path[1:]
+    i = Image.fromarray(d)
+    i.save(filepath)
\ No newline at end of file
